pub fn verify_rotation<'a>(
old: &PublicKeyBundle,
attestation: &'a RotationAttestation,
) -> Result<&'a PublicKeyBundle>Expand description
Verify a rotation attestation against the trusted old public bundle.
On success returns the authenticated successor bundle.
Errors
Error::VerificationFailed if the attestation was not signed by old
over its embedded successor.